#[non_exhaustive]pub struct AuditEvent {
pub timestamp: DateTime<Utc>,
pub event_type: String,
pub description: String,
}Expand description
A structured audit event emitted by the Forge gateway.
This is a stub that will be expanded in Phase 7 (Observability).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.timestamp: DateTime<Utc>When the event occurred.
event_type: StringThe type of event.
description: StringHuman-readable description.
Implementations